@@ -18,20 +18,28 @@
 "_PACKAGE"
 
 globalVariables(c("class_name",
+                  "class.get_patches",
                   "count",
+                  "crs",
                   "dist",
                   "extract_id",
+                  "function_name",
                   "id",
+                  "label",
                   "landscape",
                   "lsm_abbreviations_names",
                   "layer",
                   "layer2",
                   "level",
                   "metric",
+                  "metric_new",
                   "metric_1",
                   "metric_2",
                   "minp",
                   "n",
+                  "n_classes",
+                  "patch_id",
+                  "OK",
                   "value",
                   "values",
                   "x",
