@@ -108,10 +108,14 @@ lsm_c_area_sd.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_c_area_sd_calc <- function(landscape, directions){
+lsm_c_area_sd_calc <- function(landscape, directions, resolution = NULL){
 
-    area <- lsm_p_area_calc(landscape, directions = directions)
+    # get area of patches
+    area <- lsm_p_area_calc(landscape,
+                            directions = directions,
+                            resolution = resolution)
 
+    # calculate sd
     area_sd <- dplyr::summarise(dplyr::group_by(area, class),
                                 value = stats::sd(value))
 
