@@ -127,12 +127,14 @@ lsm_c_dcore_sd.list <- function(landscape, directions = 8, consider_boundary = F
                   layer = as.integer(layer))
 }
 
-lsm_c_dcore_sd_calc <- function(landscape, directions, consider_boundary, edge_depth){
+lsm_c_dcore_sd_calc <- function(landscape, directions, consider_boundary, edge_depth,
+                                points = NULL){
 
     dcore <- lsm_p_ncore_calc(landscape,
                               directions = directions,
                               consider_boundary = consider_boundary,
-                              edge_depth = edge_depth)
+                              edge_depth = edge_depth,
+                              points = points)
 
     dcore_sd <- dplyr::summarise(dplyr::group_by(dcore, class),
                                  value = stats::sd(value))
