@@ -120,11 +120,13 @@ lsm_c_enn_cv.list <- function(landscape, directions = 8, verbose = TRUE) {
                   layer = as.integer(layer))
 }
 
-lsm_c_enn_cv_calc <- function(landscape, directions, verbose) {
+lsm_c_enn_cv_calc <- function(landscape, directions, verbose,
+                              points = NULL) {
 
     enn <- lsm_p_enn_calc(landscape,
                           directions = directions,
-                          verbose = verbose)
+                          verbose = verbose,
+                          points = points)
 
     enn_cv <-  dplyr::summarize(dplyr::group_by(enn, class),
                                 value = raster::cv(value))
