@@ -112,9 +112,13 @@ lsm_l_circle_mn.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_l_circle_mn_calc <- function(landscape, directions) {
+lsm_l_circle_mn_calc <- function(landscape, directions,
+                                 resolution = NULL, points = NULL) {
 
-    circle_mn <- dplyr::summarize(lsm_p_circle_calc(landscape, directions = directions),
+    circle_mn <- dplyr::summarize(lsm_p_circle_calc(landscape,
+                                                    directions = directions,
+                                                    resolution = resolution,
+                                                    points = points),
                                   value = mean(value))
 
     tibble::tibble(
