@@ -114,9 +114,12 @@ lsm_l_gyrate_cv.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_l_gyrate_cv_calc <- function(landscape, directions) {
+lsm_l_gyrate_cv_calc <- function(landscape, directions,
+                                 points = NULL) {
 
-    gyrate_cv <- dplyr::summarize(lsm_p_gyrate_calc(landscape, directions = directions),
+    gyrate_cv <- dplyr::summarize(lsm_p_gyrate_calc(landscape,
+                                                    directions = directions,
+                                                    points = points),
                                   value = raster::cv(value))
 
     tibble::tibble(
