@@ -136,12 +136,14 @@ lsm_l_ndca.list <- function(landscape,
                   layer = as.integer(layer))
 }
 
-lsm_l_ndca_calc <- function(landscape, directions, consider_boundary, edge_depth){
+lsm_l_ndca_calc <- function(landscape, directions, consider_boundary, edge_depth,
+                            points = NULL){
 
     ndca <- dplyr::summarise(lsm_p_ncore_calc(landscape,
                                               directions = directions,
                                               consider_boundary = consider_boundary,
-                                              edge_depth = edge_depth),
+                                              edge_depth = edge_depth,
+                                              points = points),
                              value = sum(value))
 
     tibble::tibble(
