@@ -106,9 +106,12 @@ lsm_l_siei.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_l_siei_calc <- function(landscape, directions) {
+lsm_l_siei_calc <- function(landscape, directions, resolution = NULL) {
+
+    sidi <- lsm_l_sidi_calc(landscape,
+                            directions = directions,
+                            resolution = resolution)
 
-    sidi <- lsm_l_sidi_calc(landscape, directions = directions)
     pr <- lsm_l_pr_calc(landscape)
 
     siei <- sidi$value / (1 - (1 / pr$value))
