@@ -110,12 +110,25 @@ lsm_p_para.list <- function(landscape, directions = 8) {
                   layer = as.integer(layer))
 }
 
-lsm_p_para_calc <- function(landscape, directions){
+lsm_p_para_calc <- function(landscape, directions, resolution = NULL){
 
-    perimeter_patch <- lsm_p_perim_calc(landscape, directions = directions)
+    # convert to matrix
+    if(class(landscape) != "matrix") {
+        resolution <- raster::res(landscape)
+        landscape <- raster::as.matrix(landscape)
+    }
 
-    area_patch <- lsm_p_area_calc(landscape, directions = directions)
+    # get perim
+    perimeter_patch <- lsm_p_perim_calc(landscape,
+                                        directions = directions,
+                                        resolution = resolution)
 
+    # get area
+    area_patch <- lsm_p_area_calc(landscape,
+                                  directions = directions,
+                                  resolution = resolution)
+
+    # calculate ratio between area and perim
     para_patch <- dplyr::mutate(area_patch, value = perimeter_patch$value /
                                     (value * 10000))
 
